connect_to_etn() is deprecated. It is no longer supported or needed. All
connections to the ETN database are now handled automatically when you use a
function. If your credentials are not stored in the system environment, you
will be prompted to enter them.
Examples
if (FALSE) { # \dontrun{
# Before
my_connection <- connect_to_etn()
get_animals(connection = my_connection)
# Now
get_animals()
} # }