Skip to contents

Creates a bibliography from a table of detections, with references for:

  • The ETN data platform.

  • The etn R package.

  • Animal project(s) associated with the animals that were detected.

  • Acoustic project(s) associated with the receivers from which the detections were obtained.

It is recommended to cite these when using the data, see the ETN Citation Guidelines for details.

Usage

get_bibliography(detections)

Arguments

detections

A data frame containing at least the columns animal_project_code and acoustic_project_code. Typically a data frame returned by get_acoustic_detections().

Value

A data frame with three columns (item, type, and citation) containing the references.

Examples

if (FALSE) { # interactive() && etn:::credentials_are_set()
# Create a bibliography from queried detections
get_acoustic_detections(scientific_name = "Mola mola") |>
  get_bibliography()

# Or obtain the bibliography from a Data Package
read_resource(example_dataset(), "bibliography")
}