Skip to contents

Read data from a Data Resource into a tibble data frame

Usage

read_resource(package, resource_name, col_select = NULL)

Arguments

package

Data Package object, as returned by read_package() or create_package().

resource_name

Name of the Data Resource.

col_select

Character vector of the columns to include in the result, in the order provided. Selecting columns can improve read speed.

See also

Other frictionless functions: read_package(), write_package()