Gets all data related to an animal project as a Data Package.
Value
A Data Package object.
Write it to disk with write_package().
Included resources
The Data Package will contain and describe the following resources:
animals: Animals related to ananimal_project_code, as returned byget_animals().tags: Tags associated with the selected animals, as returned byget_tags().detections: Acoustic detections for the selected animals, as returned byget_acoustic_detections().deployments: Acoustic deployments for theacoustic_project_code(s) found in detections, as returned byget_acoustic_deployments(), but excluding deployments that started after the last detection. This allows you to see when and where receivers were deployed, even if these did not detect the selected animals.receivers: Acoustic receivers for the selected deployments, as returned byget_acoustic_receivers().references: References for ETN, the R package, the animal project and acoustic projects that returned detections. It is recommended to cite these when using the dataset.
Data quality
The data are downloaded from the ETN database as is, i.e. no quality or consistency checks are performed. Verifying the data before publication is therefore recommended. You can validate the technical consistency of your Data Package using Frictionless Framework with:
Examples
if (FALSE) { # etn:::credentials_are_set() & interactive()
# Get a Data Package for a project
(package <- get_package(animal_project_code = "2014_demer"))
# Read a resource
read_resource(package, "animals")
}